HexTransform class abstract

A transform for entities in a hexagonal grid world, including position, direction, and orientation.

Inheritance

Constructors

HexTransform({required HexPosition position, required HexDirection direction, required HexDirection orientation})

Properties

direction HexDirection
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
orientation HexDirection
getter/setter pairinherited
position HexPosition
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited