PlayerAchievement class abstract
Represents a player's progress or earning of an achievement.
Constructors
Properties
- achievementID ↔ String
-
The ID of the achievement associated with the player achievement.
getter/setter pair
- earnedOnTimestamp ↔ int
-
The timestamp when the achievement was earned.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
The ID of the player achievement.
getter/setter pair
- playerID ↔ String
-
The ID of the player associated with the achievement.
getter/setter pair
- progress ↔ int
-
The progress of the achievement.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited