TcpServerOnTick typedef
TcpServerOnTick =
void Function(TcpServer server)
A function that is called periodically to update the server.
Implementation
typedef TcpServerOnTick = void Function(TcpServer server);
A function that is called periodically to update the server.
typedef TcpServerOnTick = void Function(TcpServer server);