VectorTransform2D class abstract

A transform for entities in a 2D vector world, including position, direction, and orientation.

Inheritance

Constructors

VectorTransform2D({required VectorPosition2D position, required VectorPosition2D direction, required double orientation})

Properties

direction VectorPosition2D
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
orientation double
getter/setter pairinherited
position VectorPosition2D
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited