GatewayUdpServer class
Gateway endpoint that accepts UDP clients and returns routing decisions.
Constructors
- GatewayUdpServer({required int port, required GatewayRelay relay})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- relay → GatewayRelay
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → UdpServer
-
final
Methods
-
close(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited